@@ -36,6 +36,7 @@ define("eureka_instance_ip", default="", type=str, help="eureka实例ip或者域
 define("eureka_instance_port", default=8901, type=int, help="eureka实例ip或者域名")
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
+define("running_env", default="local", type=str, help="运行环境")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -51,6 +52,7 @@ options.eureka_instance_ip = ""
 options.eureka_instance_port = 8901
 options.rms_register_enable = False
 options.rms_register_server = "http://127.0.0.1:8918"
+options.running_env = "local"
 
 
 class LogFormatter(TornadoLogFormatter):
